@@ -5,12 +5,13 @@
 :synopsis: Package for D2L Valence client applications.
 :license: Apache v2.0, see LICENSE for more details.
 
-:see: http://www.desire2learn.com/r/valencehome for more information about the Valence project.
+:see: http://www.desire2learn.com/r/valencehome for more information about the
+      Valence project.
 """
 
 __title__ = 'd2lvalence'
-__version__ = '1.0.0'
-__build__ = 0x010000
+__version__ = '1.0.1'
+__build__ = 0x010001
 __author__ = 'Desire2Learn Extensibility'
 __license__ = 'Apache 2.0'
 __copyright__ = 'Copyright 2013 Desire2Learn Incorporated.'
